bootstrap.BootstrapUser

|  | ## Cheshire3 Object Model: Class BootstrapUser

Module bootstrap :: Class BootstrapUser

## Class BootstrapUser
source code

Instance Methods

hasFlag(self, session, flag, object="")

Class Variables

username |
password |
flags |

Method Details

### hasFlag(self, session, flag, object="") | source code

Class Variable Details

    ### username Value:
        'admin'

    ### password Value:
        ''

    ### flags Value:
        {'': 'c3r:administrator'}